@@ -8,15 +8,13 @@
 #include <linux/malloc.h>
 #include <linux/mm.h>
 
-#include <linux/kdes.h>
-/*#include <desitfc.h>*/
 #include <asm/segment.h>	/* for fs functions */
 #include <linux/tcfs_fs.h>
 #include <linux/tcfs.h>
 
 /* These are the function needed to handle keys hash table */
-#include "hash.h"
-#include "desitfc.h"
+#include <linux/tcfs/hash.h>
+#include <linux/tcfs/cipherinterface.h>
 
 static int tcfs_dir_open(struct inode * inode, struct file * file);
 static int tcfs_dir_read(struct inode *, struct file *, char *, int);
@@ -155,7 +153,7 @@ static int tcfs_readdir(struct inode *inode, struct file *filp,
 	struct tcfs_entry *entry;
 	struct hash_entry *htmp=NULL;
 	struct gid_hash_entry *ghtmp=NULL;
-	des_key_schedule *ks=NULL;
+	void *ks=NULL;
 	char doit=0;
 
 #ifdef DEBUG_TCFS
@@ -255,7 +253,7 @@ static int tcfs_readdir(struct inode *inode, struct file *filp,
 			if (strcmp(c_entry[i].name,".")!=0 && strcmp(c_entry[i].name,"..")!=0) {
 				k=strlen(c_entry[i].name);
 				k=tcfsdecode(c_entry[i].name,k+1);
-				kdedes(c_entry[i].name,(k & 0xfff8)+8,ks);
+				tcfs_decrypt(c_entry[i].name,(k & 0xfff8)+8,ks);
 			}
 		}
 	}
@@ -436,7 +434,7 @@ int tcfs_lookup(struct inode *dir, const char *__name, int len,
 	int error,k;
 	struct hash_entry * htmp=NULL;
 	struct gid_hash_entry *ghtmp=NULL;
-	des_key_schedule *ks=NULL;
+	void *ks=NULL;
 	char doit=0;
 
 #ifdef DEBUG_TCFS
@@ -488,7 +486,7 @@ int tcfs_lookup(struct inode *dir, const char *__name, int len,
 	/* Handle cryptographed file names */
 	if (doit && (strcmp(name,".")!=0 && strcmp(name,"..")!=0)) {
 		k=len+1;
-		kendes(name,(k & 0xfff8)+8,ks);
+		tcfs_encrypt(name,(k & 0xfff8)+8,ks);
 		tcfsencode(name,(k & 0xfff8)+8);
 		len=strlen(name);
 	}
@@ -564,7 +562,7 @@ static int tcfs_create(struct inode *dir, const char *name, int len, int mode,
 	struct hash_entry *htmp=NULL;
 	int error,k;
 	struct gid_hash_entry *ghtmp=NULL;
-	des_key_schedule *ks=NULL;
+	void *ks=NULL;
 	char doit=0;
 #ifdef DEBUG_TCFS
 	printk("TCFS: tcfs_create %s\n",name);
@@ -619,7 +617,7 @@ static int tcfs_create(struct inode *dir, const char *name, int len, int mode,
 	}
 	if (doit && (strcmp(newname,".")!=0 && strcmp(newname,"..")!=0)) {
 			k=strlen(newname)+1;
-			kendes(newname,(k & 0xfff8)+8,ks);
+			tcfs_encrypt(newname,(k & 0xfff8)+8,ks);
 			tcfsencode(newname,(k & 0xfff8)+8);
 	}
 	if ((error = tcfs_proc_create(TCFS_SERVER(dir), TCFS_FH(dir),
@@ -664,7 +662,7 @@ static int tcfs_mknod(struct inode *dir, const char *name, int len,
 	struct hash_entry *htmp=NULL;
 	int error,k;
 	struct gid_hash_entry *ghtmp;
-	des_key_schedule *ks;
+	void *ks;
 	char doit=0;
 
 #ifdef DEBUG_TCFS
@@ -714,7 +712,7 @@ static int tcfs_mknod(struct inode *dir, const char *name, int len,
 	}
 	if (doit && (strcmp(newname,".")!=0 && strcmp(newname,"..")!=0)) {
 		k=strlen(newname)+1;
-		kendes(newname,(k & 0xfff8)+8,htmp->ks);
+		tcfs_encrypt(newname,(k & 0xfff8)+8,htmp->ks);
 		tcfsencode(newname,(k & 0xfff8)+8);
 	}
 	error = tcfs_proc_create(TCFS_SERVER(dir), TCFS_FH(dir),
@@ -739,7 +737,7 @@ static int tcfs_mkdir(struct inode *dir, const char *name, int len, int mode)
 	struct hash_entry *htmp=NULL;
 	int error,k;
 	struct gid_hash_entry *ghtmp=NULL;
-	des_key_schedule *ks=NULL;
+	void *ks=NULL;
 	char doit=0;
 	unsigned int newmode=0;
 #ifdef DEBUG_TCFS
@@ -787,7 +785,7 @@ static int tcfs_mkdir(struct inode *dir, const char *name, int len, int mode)
 	}
 	if (doit && (strcmp(newname,".")!=0 && strcmp(newname,"..")!=0)) {
 		k=strlen(newname)+1;
-		kendes(newname,(k & 0xfff8)+8,ks);
+		tcfs_encrypt(newname,(k & 0xfff8)+8,ks);
 		tcfsencode(newname,(k & 0xfff8)+8);
 	}
 	error = tcfs_proc_mkdir(TCFS_SERVER(dir), TCFS_FH(dir),
@@ -821,7 +819,7 @@ static int tcfs_rmdir(struct inode *dir, const char *name, int len)
 	char newname[TCFS_MAXPATHLEN+1];
 	struct hash_entry *htmp;
 	struct gid_hash_entry *ghtmp;
-	des_key_schedule *ks=NULL;
+	void *ks=NULL;
 	char doit=0;
 #ifdef DEBUG_TCFS
 	printk("TCFS: tcfs_rmdir %s\n",name);
@@ -863,7 +861,7 @@ static int tcfs_rmdir(struct inode *dir, const char *name, int len)
 	}
 	if (doit && (strcmp(newname,".")!=0 && strcmp(newname,"..")!=0)) {
 		k=strlen(newname)+1;
-		kendes(newname,(k & 0xfff8)+8,ks);
+		tcfs_encrypt(newname,(k & 0xfff8)+8,ks);
 		tcfsencode(newname,(k & 0xfff8)+8);
 	}
 	error = tcfs_proc_rmdir(TCFS_SERVER(dir), TCFS_FH(dir), newname);
@@ -873,7 +871,7 @@ static int tcfs_rmdir(struct inode *dir, const char *name, int len)
 	return error;
 }
 
-static int tcfs_sillyrename(struct inode *dir, const char *name, char *newname,int len,des_key_schedule *ks)
+static int tcfs_sillyrename(struct inode *dir, const char *name, char *newname,int len,void *ks)
 {
 	struct inode	*inode;
 	char		silly[256];
@@ -898,7 +896,7 @@ static int tcfs_sillyrename(struct inode *dir, const char *name, char *newname,i
 	}
 	if (TCFS_IS_SHARED(inode) || TCFS_IS_SECURE(dir->u.tcfs_i.tcfs_fl.cflag)) {
 		k=slen+1;
-		kendes(silly,(k & 0xfff8)+8,ks);
+		tcfs_encrypt(silly,(k & 0xfff8)+8,ks);
 		tcfsencode(silly,(k & 0xfff8)+8);
 	}
 	
@@ -938,7 +936,7 @@ static int tcfs_unlink(struct inode *dir, const char *name, int len)
 	char newname[TCFS_MAXPATHLEN+1];
 	struct hash_entry * htmp=NULL;
 	struct gid_hash_entry *ghtmp;
-	des_key_schedule *ks=NULL;
+	void *ks=NULL;
 	char doit=0;
 
 #ifdef DEBUG_TCFS
@@ -982,7 +980,7 @@ static int tcfs_unlink(struct inode *dir, const char *name, int len)
 	}
 	if (doit && (strcmp(newname,".")!=0 && strcmp(newname,"..")!=0)) {
 		k=len+1;
-		kendes(newname,(k & 0xfff8)+8,ks);
+		tcfs_encrypt(newname,(k & 0xfff8)+8,ks);
 		tcfsencode(newname,(k & 0xfff8)+8);
 	}
 	if ((error = tcfs_sillyrename(dir, name, newname, len, ks)) < 0) {
@@ -1002,7 +1000,7 @@ static int tcfs_symlink(struct inode *dir, const char *name, int len,
 	char newname[TCFS_MAXPATHLEN+1];
 	struct hash_entry *htmp=NULL;
 	struct gid_hash_entry *ghtmp=NULL;
-	des_key_schedule *ks=NULL;
+	void *ks=NULL;
 	char doit=0;
 
 #ifdef DEBUG_TCFS
@@ -1050,7 +1048,7 @@ static int tcfs_symlink(struct inode *dir, const char *name, int len,
 	}
 	if (doit && (strcmp(newname,".")!=0 && strcmp(newname,"..")!=0)) {
 		k=strlen(newname)+1;
-		kendes(newname,(k & 0xfff8)+8,ks);
+		tcfs_encrypt(newname,(k & 0xfff8)+8,ks);
 		tcfsencode(newname,(k & 0xfff8)+8);
 	}
 	sattr.mode = S_IFLNK | S_IRWXUGO; /* SunOS 4.1.2 crashes without this! */
@@ -1070,7 +1068,7 @@ static int tcfs_link(struct inode *oldinode, struct inode *dir,
 	char newname[TCFS_MAXPATHLEN+1];
 	struct hash_entry * htmp=NULL;
 	struct gid_hash_entry *ghtmp=NULL;
-	des_key_schedule *ks=NULL;
+	void *ks=NULL;
 	char doit=0;
 
 #ifdef DEBUG_TCFS
@@ -1118,7 +1116,7 @@ static int tcfs_link(struct inode *oldinode, struct inode *dir,
 	}
 	if (doit && (strcmp(newname,".")!=0 && strcmp(newname,"..")!=0)) {
 		k=strlen(newname)+1;
-		kendes(newname,(k & 0xfff8)+8,ks);
+		tcfs_encrypt(newname,(k & 0xfff8)+8,ks);
 		tcfsencode(newname,(k & 0xfff8)+8);
 	}
 	error = tcfs_proc_link(TCFS_SERVER(oldinode), TCFS_FH(oldinode),
@@ -1138,7 +1136,7 @@ static int tcfs_rename(struct inode *old_dir, const char *old_name, int old_len,
 	struct hash_entry *htmp=NULL;
 	char oldname[TCFS_MAXPATHLEN+1], newname[TCFS_MAXPATHLEN+1];
 	struct gid_hash_entry *ghtmp=NULL;
-	des_key_schedule *oks=NULL,*nks=NULL;
+	void *oks=NULL, *nks=NULL;
 	char doit1=0,doit2=0;
 
 #ifdef DEBUG_TCFS
@@ -1209,13 +1207,13 @@ static int tcfs_rename(struct inode *old_dir, const char *old_name, int old_len,
 	}
 	if (doit1 && (strcmp(oldname,".")!=0 && strcmp(oldname,"..")!=0)) {
 		k=old_len+1;
-		kendes(oldname,(k & 0xfff8)+8,oks);
+		tcfs_encrypt(oldname,(k & 0xfff8)+8,oks);
 		tcfsencode(oldname,(k & 0xfff8)+8);
 	}
 	strcpy(newname,new_name);
 	if (doit2 && (strcmp(newname,".")!=0 && strcmp(newname,"..")!=0)) {
 		k=new_len+1;
-		kendes(newname,(k & 0xfff8)+8,nks);
+		tcfs_encrypt(newname,(k & 0xfff8)+8,nks);
 		tcfsencode(newname,(k & 0xfff8)+8);
 	}
 	error = tcfs_proc_rename(TCFS_SERVER(old_dir),
